summaryrefslogtreecommitdiffstats
path: root/tdecore/tdemacros.h.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tdemacros.h.cmake')
-rw-r--r--tdecore/tdemacros.h.cmake11
1 files changed, 7 insertions, 4 deletions
diff --git a/tdecore/tdemacros.h.cmake b/tdecore/tdemacros.h.cmake
index b8d5abd43..543e3f8f0 100644
--- a/tdecore/tdemacros.h.cmake
+++ b/tdecore/tdemacros.h.cmake
@@ -1,5 +1,5 @@
-/* This file is part of the KDE libraries
- Copyright (c) 2002-2003 KDE Team
+/* This file is part of the TDE libraries
+ Copyright (c) 2002-2003 TDE Team
This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
@@ -22,7 +22,10 @@
/* Set by configure */
#cmakedefine __TDE_HAVE_TDEHWLIB 1
-#cmakedefine __KDE_HAVE_GCC_VISIBILITY 1
+#cmakedefine __TDE_HAVE_GCC_VISIBILITY 1
+#ifdef __TDE_HAVE_GCC_VISIBILITY
+#define __KDE_HAVE_GCC_VISIBILITY __TDE_HAVE_GCC_VISIBILITY
+#endif
/**
* The TDE_NO_EXPORT macro marks the symbol of the given variable
@@ -38,7 +41,7 @@
* \end
*/
-#ifdef __KDE_HAVE_GCC_VISIBILITY
+#ifdef __TDE_HAVE_GCC_VISIBILITY
#define TDE_NO_EXPORT __attribute__ ((visibility("hidden")))
#define TDE_EXPORT __attribute__ ((visibility("default")))
#elif defined(TQ_WS_WIN)